@part<three,root="mm.mss">
@begin(text)
@Chapter(Message Sequences)@tag<messseq>

@Section(Message Sequences)
@blankspace<1 line>

When you are working in @b(read mode) or @b(send mode), any command
you enter will apply either to the message you are reading or to the
outgoing message.  At @b(top level), however, commands can apply to
any or all of the messages in your mailbox.  You may, for example,
want to read all messages from a particular person about a certain
subject.  Or perhaps you'd like to delete any message about a meeting
or class once the event has passed.  Message sequences make this
possible.

A message sequence is a word or phrase that describes some group of
messages that have a particular trait in common.

The simplest form is a number or range of numbers.  For example,
messages 5 through 10 can be specified as follows:@ @ @ @ @ 5:10@ @ @
@ @ 5-10@ @ @ @ @ 5,6,7,8,9,10@ @ @ @ @ 5+6

Asterisk (*) means the last message, the highest-numbered message.

There are many other message sequences, listed below.  Some require a
value as suggested in <> brackets.  Type @i<help message-sequence> to
list them online.

@section(Description of Message Sequences)
@blankspace(1 line)
@end(text)
@begin(text2, columnbalance=on)

@begin(itemize) 

AFTER <date>: all messages sent or received after a certain date or
day, as @i(after April 1, 1989) or @i(after Tuesday).  A time can be
specified after the date or day, as @i<after Tuesday 1:00pm>.

ALL: every message in your file, including any marked for deletion,
from oldest to newest.  See also INVERSE.

ANSWERED: messages you have @i<reply>'d to or @i<answer>ed.

BEFORE <date>: all messages sent or received before a certain date or
day.  See AFTER.

CURRENT: the message MM is pointing at, for example, the last one
@i(read).  Also abbreviated as period (@.).

DELETED: messages that have been marked for deletion with the
@i<delete> command, or moved using the @i<move> command.  On a
subsequent @i<expunge> or @i<exit> command, the deleted messages will
be physically removed from your mail file and gone forever.

FLAGGED: messages marked by the @i(flag) command.

FROM <user>: messages from a person.  It searches both the user ID and
the name in the @i(from) field, so note, for example, that @i(from
sue) matches the user ID @i(sue) but also anyone else named Sue.  Be
careful when deleting @i(from) a name.

INVERSE: all messages, like ALL, but in inverse order (most recent
message first).

KEYWORD <keyword-name>: messages marked by the @i(keyword) command.
You can define keywords to mark groups of messages by a keyword name.
Whenever you want to refer to the messages marked with a certain
keyword, you type a two word sequence: @i[keyword <keyword-name>].

LAST: the last message.  Also abbreviated as asterisk (*).

LAST <number>: the last @i(n) messages.

LONGER <number>: all messages containing more than, or exactly, a
certain number of characters.

NEW: messages that are both @i<recent> and @i<unseen>.  Generally this
is a message that has arrived while you were away from the computer,
or perhaps one that has just arrived while you were working.

ON <date>: messages sent or received on a certain date or day.  See
AFTER.

PREVIOUS SEQUENCE: the last message sequence used in an MM command.
You might preview a sequence by typing something like @i<headers
<message sequence>>, and then, if it is what you want, type @i<read
previous sequence> rather than retyping the same message sequence
again.

RECENT: messages that are new as of this session with MM.  If you have
5 new messages when you log in, then they would all be marked
@i<recent> until you've ended your session with MM.

SEEN: messages you have already looked at.  Most likely all or nearly
all the messages in your mailbox are considered @i<seen> since you
usually read any @i(unseen) ones when you start MM.  A message that is
marked @i<seen> will not have a U or N next to its header.

SHORTER <number>: all messages containing fewer than a certain number
of characters.

SINCE <date>: messages sent or received on or after a certain date or
day.  See AFTER.  Unlike @i<after>, @i<since> includes the date
specified.

SUBJECT <word>: all messages that have a certain word (or part of a
word) in their subject field.  For example, to see messages that have
"computer" in the subject, use @i<subject computer>.  

TEXT <word>: all messages that have a certain word (or part of a word)
in their text.  For example, the word "computer" might not be in the
subject field of some messages, but you can reference all messages
that mention "computer" in their text by @i<text computer>.  You might
try part of the word instead, like @i<text comput>, to include
"computing", "compute", etc as well.

TO <user>: all messages that were sent to a user, including carbon
copies, but not blind carbon copies (the "cc" but not "bcc" header
fields).  Most of the messages in your mailbox are @i<to> yourself,
but you may have some @i<to> other people that are cc'd to yourself,
and some that were @i<to> other people besides yourself.

UNANSWERED: messages you did not @i<reply> to or @i(answer).

UNDELETED: messages that haven't been deleted via the @i<delete> or
@i<move> commands.

UNFLAGGED: messages not @i<flag>ged.

UNKEYWORD <keyword-name>: messages not included in the keyword.

UNSEEN: messages that were never @i<type>d or @i<read>.

@end(itemize)
@end(text2)

@begin(text)
@Section[Message Sequence examples]
@end(text)
@begin(text2, columnbalance=on)

Here are some simple examples of commands using message sequences.
You may also use several in one command to further specify the desired
messages.

This would put you into @b<read mode> and would let you read all the
@i[flag]ged messages:

@begin(example)
MM>@p(read flagged <cr>)
@end(example)

This would read all the messages from hmh:

@begin(example) 
MM>@p(read from hmh <cr>)
@end(example)

This would read messages 3 through 8 individually:

@begin(example)
MM>@p(read 3:8 <cr>)
@end(example)

This would display the header lines of all the messages that are
unanswered from hmh (note that two message sequences are combined,
@i<from> and @i<unanswered>):

@begin(example)
MM>@p(hea from hmh unanswered <cr>)
@end(example)

This command marks for deletion all messages from 5 through 15 that
contain the string "deadline" in the text of the message:

@begin(example)
MM>@p(delete 5:15 text deadline <cr>)
@end(example)

This would display the header lines of all messages you have received
since (and including) Monday:

@begin(example)
MM>@p(headers since Monday <cr>)
@end(example)

@end<text2>



