@device(postscript)
@Comment[]
@make(manual)
@comment[Make the Table of Contents go to a disk file mm.toc]
@comment[The *previous* version gets inserted into mm.ps file]
@comment[Run scribe twice if contents change affecting paging]
@generate(contents="toc")

@comment[Possibly used to format the one table]
@Libraryfile(Stable)

@Comment(Standard font for CUCCA guides)
@style{font palatino} 
@style{size=10}

@Comment(Standard spacing for CUCCA guides)
@style(leftmargin 3 cm)
@style(rightmargin 3 cm)
@style(bottommargin 3 cm)
@style(topmargin 4.5 cm)
@style<doublesided,bindingmargin 2 cm>

@style<widowaction=force>
@modify(text, spacing 1)

@comment<2- columned environment>
@define<text2=text> 
@modify(text2, columns 2, columnwidth 8.1 cm,
  columnmargin  .7 cm, boxed, spacing 1, indent 0)

@Comment(The example environment is boxed with a smaller font for mm examples)
@modify[example, use box, size -2, above 1, below 1]

@comment<Redefine flushleft and right for larger sized page numbers in
         pageheading definition (see below)>
@define<fl=flushleft>
@define<fr=flushright>
@modify<fl,size +5>
@modify<fr,size +5>

@Comment(Special indentation for itemize)
@Define(Itemize2=itemize)
@modify(itemize2,LeftMargin +8) @comment{dropped this:,Numbered <@@zs[*]>)}

@Comment[Changing some values set in manual.mak]
@Comment[Hd1 is for Appendix, Chapter and Preface Titles]                  
@modify(Hd1, above 2, below 2, Pagebreak Before,boxed)
@Comment[Hd2 is for Sections, Appendix Section]
@modify(Hd2, above 2, below 1,size 12,flushleft,boxed)
@Comment[Hd3 is for Subsection and Appendix Subsection]
@modify(Hd3, above 2, below 1,size 10,flushleft,boxed)
@Comment[Hd4, is for Paragraph within subsection]  
@modify(Hd4, above 2, below 1,size 10,boxed)
@Comment(Tc1 is for Table of Contents chapter titles)
@modify(Tc1, need 0 inch)
@Comment(Tc2 is for Table of Contents section titles-complete redefinition)
@define(Tc2, LeftMargin 8, Indent -5, RightMargin 5, Fill, Spaces compact,
        Spacing 1, Break, Justification off)
@Comment(Hd1A is title "Table of Contents" and prefacesection)
@modify(Hd1A, flushleft, below 1, Pagebreak Before)

@comment[Remove numbering for everything but Chapters.]
@Modify(Section,Numbered [*])
@Modify(AppendixSection,Numbered [*])
@Modify(SubSection,Numbered [*])
@Modify(AppendixSubSection,Numbered [*])
@Modify(Paragraph,Numbered [*])

@pageheading(even,immediate)
@pageheading(odd,immediate)
@modify(titlepage, sink .5in)
@modify(titlebox, fixed 1in)
@begin(titlepage)
 @begin(titlebox)
  @blankspace(3 in)
  @begin(center, size +10)
   @b<MM Electronic Mail>
   @b<>
   @b<User Manual>
  @end(center)
  @blankspace(2 in)
  @heading(Joseph Brennan)
  @heading(Columbia University Center for Computing Activities)
  @heading(Academic Computing Consulting Services)
  @blankspace(2 lines)
  March 1990 Edition, revised December 1990
 @end(titlebox)
@end(titlepage)

@set<page=2>
@newpage<>
@blankspace<3.0 inches>
@copyright(@value[year] Columbia University Center for Computing Activities)
@blankspace<1 inch>
@begin(text)
Some of the content of this manual is taken from earlier MM Manuals written 
by Sue Zayac, Lisa Covi and Lynn Jacobsen.  The current editor and writer is
Joseph Brennan, e-mail address brennan@@cunixf.cc.columbia.edu.  Comments and
suggestions for improvements in future editions are welcome.  

The Unix version of MM was written with CCMD at Columbia University by
Chris Maio, Howie Kaye, Fuat Baran, and Melissa Metz.  CCMD was also
written at Columbia University, by Andrew Lowry and Howie Kaye.

The original MM for DEC20s (and its design) was written by a number of
people, including Michael McMahon, Stuart McLure Cracraft, Ted Hess and
Mark Crispin.

@end(text)

@Comment(Table of Contents; instructions within "toc" start new page,)
@Comment(so here we do *not* say "immediate" nor state "newpage")
@pageheading [odd, line "@bar<>@fl(Contents)"]
@pagefooting [line "@bar<>"]
@include<mm.toc>

@newpage<>
@Comment(Preface)
@pageheading [immediate, line "@bar<>@fr(Preface)"]
@pagefooting [immediate, line "@bar<>"]

@include (00-preface-ps)

@newpage<>
@set(page=1)
@style<pagenumber "@1">
@pageheading [immediate, even, 
   line "@bar<>@fr(@title{chapter}) @fl(@value{page})"]
@pageheading [immediate, odd, 
   line "@bar<>@fl(@title{chapter}) @fr(@value{page})"]
@pagefooting(immediate, line "@bar<>")

@include(01-intro-ps)

@newpage<>
@include(02-samples-ps)

@newpage<>
@include(03-messseq-ps)

@newpage<>
@include(04-top-ps)

@newpage<>
@include(05-read-ps)

@newpage<>
@include(06-send-ps)

@newpage<>
@include(07-custom-ps)

@newpage<>
@include(08-hints-ps)

